==> react-molecule-avatar-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["className", "size", "skeleton", "name", "src", "fallbackIcon", "style", "isLoading", "imageProps", "children"];
import { forwardRef, useCallback } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomImage from '@s-ui/react-atom-image';
import AtomSkeleton, { ATOM_SKELETON_ANIMATIONS, ATOM_SKELETON_VARIANTS } from '@s-ui/react-atom-skeleton';
import Injector from '@s-ui/react-primitive-injector';
import AvatarBadge, { AVATAR_BADGE_PLACEMENTS, AVATAR_BADGE_SIZES, AVATAR_BADGE_STATUSES } from './AvatarBadge/index.js';
import AvatarFallback from './AvatarFallback/index.js';
import { AVATAR_SIZES, baseClassName } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeAvatar = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var classNameProp = _ref.className,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? AVATAR_SIZES.MEDIUM : _ref$size,
      _ref$skeleton = _ref.skeleton,
      skeleton = _ref$skeleton === void 0 ? /*#__PURE__*/_jsx(AtomSkeleton, {
    width: "100%",
    height: "100%",
    variant: ATOM_SKELETON_VARIANTS.circle,
    animation: ATOM_SKELETON_ANIMATIONS.wave
  }) : _ref$skeleton,
      name = _ref.name,
      src = _ref.src,
      fallbackIcon = _ref.fallbackIcon,
      style = _ref.style,
      isLoading = _ref.isLoading,
      _ref$imageProps = _ref.imageProps,
      imageProps = _ref$imageProps === void 0 ? {} : _ref$imageProps,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var className = cx(baseClassName, baseClassName + "--" + size);
  var renderContent = useCallback(function () {
    if (isLoading) {
      return skeleton;
    }

    var fallback = /*#__PURE__*/_jsx(AvatarFallback, {
      name: name,
      size: size,
      icon: fallbackIcon
    });

    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [src ? /*#__PURE__*/_jsx(AtomImage, _extends({
        src: src,
        alt: name,
        errorIcon: fallback
      }, imageProps)) : fallback, !isLoading && /*#__PURE__*/_jsx(Injector, {
        size: size,
        children: children
      })]
    });
  }, [children, fallbackIcon, isLoading, name, size, skeleton, src, imageProps]);
  return /*#__PURE__*/_jsx("span", _extends({
    style: style,
    className: className
  }, others, {
    ref: forwardedRef,
    children: renderContent()
  }));
});
MoleculeAvatar.displayName = 'MoleculeAvatar';
MoleculeAvatar.Badge = AvatarBadge;
export { AVATAR_SIZES as MOLECULE_AVATAR_SIZES };
export { AVATAR_SIZES as moleculeAvatarSizes };
export { AVATAR_BADGE_STATUSES as MOLECULE_AVATAR_BADGE_STATUSES };
export { AVATAR_BADGE_STATUSES as moleculeAvatarBadgeStatuses };
export { AVATAR_BADGE_PLACEMENTS as MOLECULE_AVATAR_BADGE_PLACEMENTS };
export { AVATAR_BADGE_PLACEMENTS as moleculeAvatarBadgePlacements };
export { AVATAR_BADGE_SIZES as MOLECULE_AVATAR_BADGE_SIZES };
export { AVATAR_BADGE_SIZES as moleculeAvatarBadgeSizes };
export default MoleculeAvatar;

==> react-molecule-avatar-1.17.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["className", "size", "skeleton", "name", "src", "fallbackColor", "fallbackIcon", "style", "isLoading", "imageProps", "children"];
import { forwardRef, useCallback } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomImage from '@s-ui/react-atom-image';
import AtomSkeleton, { ATOM_SKELETON_ANIMATIONS, ATOM_SKELETON_VARIANTS } from '@s-ui/react-atom-skeleton';
import Injector from '@s-ui/react-primitive-injector';
import AvatarBadge, { AVATAR_BADGE_PLACEMENTS, AVATAR_BADGE_SIZES, AVATAR_BADGE_STATUSES } from './AvatarBadge/index.js';
import AvatarFallback from './AvatarFallback/index.js';
import { AVATAR_SIZES, baseClassName } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeAvatar = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var classNameProp = _ref.className,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? AVATAR_SIZES.MEDIUM : _ref$size,
    _ref$skeleton = _ref.skeleton,
    skeleton = _ref$skeleton === void 0 ? /*#__PURE__*/_jsx(AtomSkeleton, {
      width: "100%",
      height: "100%",
      variant: ATOM_SKELETON_VARIANTS.circle,
      animation: ATOM_SKELETON_ANIMATIONS.wave
    }) : _ref$skeleton,
    name = _ref.name,
    src = _ref.src,
    fallbackColor = _ref.fallbackColor,
    fallbackIcon = _ref.fallbackIcon,
    style = _ref.style,
    isLoading = _ref.isLoading,
    _ref$imageProps = _ref.imageProps,
    imageProps = _ref$imageProps === void 0 ? {} : _ref$imageProps,
    children = _ref.children,
    others = _objectWithoutPropertiesLoose(_ref, _excluded);
  var className = cx(baseClassName, baseClassName + "--" + size);
  var renderContent = useCallback(function () {
    if (isLoading) {
      return skeleton;
    }
    var fallback = /*#__PURE__*/_jsx(AvatarFallback, {
      name: name,
      size: size,
      icon: fallbackIcon,
      backgroundColor: fallbackColor
    });
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [src ? /*#__PURE__*/_jsx(AtomImage, _extends({
        src: src,
        alt: name,
        errorIcon: fallback
      }, imageProps)) : fallback, !isLoading && /*#__PURE__*/_jsx(Injector, {
        size: size,
        children: children
      })]
    });
  }, [children, fallbackColor, fallbackIcon, isLoading, name, size, skeleton, src, imageProps]);
  return /*#__PURE__*/_jsx("span", _extends({
    style: style,
    className: className
  }, others, {
    ref: forwardedRef,
    children: renderContent()
  }));
});
MoleculeAvatar.displayName = 'MoleculeAvatar';
MoleculeAvatar.Badge = AvatarBadge;
export { AVATAR_SIZES as MOLECULE_AVATAR_SIZES };
export { AVATAR_SIZES as moleculeAvatarSizes };
export { AVATAR_BADGE_STATUSES as MOLECULE_AVATAR_BADGE_STATUSES };
export { AVATAR_BADGE_STATUSES as moleculeAvatarBadgeStatuses };
export { AVATAR_BADGE_PLACEMENTS as MOLECULE_AVATAR_BADGE_PLACEMENTS };
export { AVATAR_BADGE_PLACEMENTS as moleculeAvatarBadgePlacements };
export { AVATAR_BADGE_SIZES as MOLECULE_AVATAR_BADGE_SIZES };
export { AVATAR_BADGE_SIZES as moleculeAvatarBadgeSizes };
export default MoleculeAvatar;
